@@ -4,14 +4,14 @@ from pwnlib                 import *
 # Promote functions from these modules to toplevel
 from pwnlib.asm             import *
 from pwnlib.ui              import *
-from pwnlib.util            import crc
+from pwnlib.util            import crc, proc
 from pwnlib.util.cyclic     import *
 from pwnlib.util.fiddling   import *
 from pwnlib.util.hashes     import *
 from pwnlib.util.lists      import *
 from pwnlib.util.misc       import *
 from pwnlib.util.packing    import *
-from pwnlib.util.proc       import *
+from pwnlib.util.proc       import pidof
 from pwnlib.util.splash     import *
 from pwnlib.tubes.remote    import *
 from pwnlib.tubes.listen    import *
