@@ -1,7 +1,7 @@
 __all__ = [
     'crc', 'cyclic', 'fiddling', 'hashes', 'lists',
-    'misc', 'packing', 'proc', 'safeeval'
+    'misc', 'packing', 'proc', 'safeeval', 'net'
 ]
 
 from . import crc, cyclic, fiddling, hashes, lists
-from . import misc, packing, proc, safeeval
+from . import misc, packing, proc, safeeval, net
